<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.log_monitor.log_database_handler`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**
- **db_conn_name**
- **initial_sql**
- **insertion_sql**


---

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L62"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `DatabaseHandler`




<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L66"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `DatabaseHandler.__init__`

```python
__init__(database_name)
```






---

#### <kbd>property</kbd> DatabaseHandler.name







---

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L78"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `DatabaseHandler.emit`

```python
emit(record)
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L75"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `DatabaseHandler.format_time`

```python
format_time(record)
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L96"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>classmethod</kbd> `DatabaseHandler.register_callback`

```python
register_callback(cb)
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_database_handler.py#L100"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `DatabaseHandler.write`

```python
write(m)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
